<?php
$page_title = "お問い合わせ - 入力内容確認";
include_once('site_config.php');
include_once('template/base_site_head.php');
?>
    <!-- メインエリア -->
	<link rel="stylesheet" type="text/css" href="../../files/css/newstyle.css">
<wrapper>
	<section class="container page-container">
		<div class="row page-title">
			<div class="col-sm-12">
				<h1 class="blue-line-ctr"><?php echo $page_title; ?></h1>
			</div>
		</div>
		<div class="row no-border">
			<div class="col-sm-12">
				<h5 style="color: #f00f00; line-height: 1.75;">
				＊サーバーの不具合により、以下のお問い合わせフォームから送信されたお客様のメールが受信ができない状態が続いております。お手数ですが、当該機能を修正できるまで、お問い合わせの際は <img src="../../files/img/cs_iwl_world.PNG" alt="cs-iwl-world" class="img-responsive" style="display:inline-block; height:22px; margin-top: -2px;"> まで直接メールにてご連絡ください。
				<br><br>
				</h5>
				<h5>お問い合わせの前にFAQをご覧ください。</h5>
				<p>下記フォームにお問い合わせ内容をご記入ください。<br>
      お返事は、原則として翌営業日までにEメールにてお答えさせて頂きます。但し、土日祝・夏季・冬季休業日のお問合せは、お待たせする場合がございます。<br>
      弊社からのお返事は、お客様個人宛てにお送りするものです。お返事文面の一部または全部を転載、二次利用することはご遠慮ください。<br>
      英語、日本語、中国語、韓国語のお問い合わせに対応いたします。</p>
			</div>
			
		</div>   

		<div class="row">
			<div class="col-sm-12"> 
				<ul class="nav nav-pills">
			
					<li><a><?php $this -> dispAccountTypeString(); ?></a></li>
				</ul>
			</div>
		</div>
		<div class="tab-content">
			<div id="personal" class="tab-pane fade in active">	
				<div class="row">
					<div class="col-sm-8">

      <form id="acForm" action="" method="post" class="support-form">

		<div class="form-group row info-section">
			<label class="col-sm-3 info-label" for="email">メールアドレス:

			</label>
			<div class="col-sm-9 input-box">
				<?php $this -> echoEmail(); ?>
			</div>					
		</div>
		<?php $this -> dispConfirm(); ?>

		<div class="form-group row info-section">
			<label class="col-sm-3 info-label" for="inquiry-subject">お問い合わせ件名:

			</label>
			<div class="col-sm-9 input-box">
				<?php $this -> echoTitle(); ?>
			</div>
		</div>
		<div class="form-group row info-section">
			<label class="col-sm-3 info-label" for="inquiry-content">お問い合わせ内容:

			</label>
			<div class="col-sm-9 input-box">
				<?php $this -> dispBody(); ?>
			</div>
		</div>
<a href="#" id="btnBack" class="btn"><i class=" fa fa-arrow-left"></i>入力ページへ戻る</a>&nbsp;
<div class="col-sm-12 btn-box">	

        <button class="btn-left" id="btnComplete" type="submit" value="Send">この内容で送信する</button></p>

        <input type="hidden" id="type" name="type" value="" />

        <input type="hidden" id="email" name="email" value="<?php $this -> echoEmail(); ?>" />
        <input type="hidden" id="re_email" name="re_email" value="<?php $this -> echoReEmail(); ?>" />
        <input type="hidden" id="name_corp" name="name_corp" value="<?php $this -> echoName(); ?>" />
        <input type="hidden" id="manager_name" name="manager_name" value="<?php $this -> echoManager(); ?>" />
        <input type="hidden" id="name_per" name="name_per" value="<?php $this -> echoName(); ?>" />
        <input type="hidden" id="title" name="title" value="<?php $this -> echoTitle(); ?>" />
        <input type="hidden" id="body" name="body" value="<?php $this -> echoBody(); ?>" />
		
									 					
		</div>
	
      </form>
			</div>
		</div>
	</div>	
  </div>	
    <script src="../js/support.js"></script>
			
	</section>
</wrapper>
    <!-- /メインエリア -->
<?php
include_once('template/base_site_foot.php');
echo $endscripts;
?>
</body>
</html>